@@ -97,7 +97,7 @@ paths_to_cats = (
 
 
 def _determine_pf_parts(fs, paths, gather_statistics, **kwargs):
-    """ Determine how to access metadata and break read into ``parts``
+    """Determine how to access metadata and break read into ``parts``
 
     This logic is mostly to handle `gather_statistics=False` cases,
     because this also means we should avoid scanning every file in the
@@ -510,6 +510,7 @@ class FastParquetEngine(Engine):
         partition_on=None,
         ignore_divisions=False,
         division_info=None,
+        schema=None,
         **kwargs
     ):
         if append and division_info is None:
@@ -579,7 +580,8 @@ class FastParquetEngine(Engine):
             )
             i_offset = 0
 
-        return (fmd, i_offset)
+        schema = None  # ArrowEngine compatibility
+        return (fmd, schema, i_offset)
 
     @classmethod
     def write_partition(
