@@ -947,10 +947,9 @@ class SubgraphCallable(object):
     def __eq__(self, other):
         return (
             type(self) is type(other)
-            and self.dsk == other.dsk
+            and self.name == other.name
             and self.outkey == other.outkey
             and set(self.inkeys) == set(other.inkeys)
-            and self.name == other.name
         )
 
     def __ne__(self, other):
@@ -963,3 +962,6 @@ class SubgraphCallable(object):
 
     def __reduce__(self):
         return (SubgraphCallable, (self.dsk, self.outkey, self.inkeys, self.name))
+
+    def __hash__(self):
+        return hash(tuple((self.outkey, tuple(self.inkeys), self.name)))
